@@ -1,5 +1,7 @@
-# -*- coding: utf-8 -*-
-from pyeph.decorators import translate_params
+import pandas as pd
+
+from pyeph.tools.decorators import translate_params
+from pyeph.tools.labels import vars_labels
 
 from ..getter import Getter
 from .validator import MicroDataValidator
@@ -39,17 +41,16 @@ class MicroData(Getter, MicroDataValidator):
 		'tipo_base': 'base_type'
 	})
 	def __init__(self,
-			year,
-			period,
-			freq="trimestre",
-			base_type="individual",
-			*args, **kwargs
+			year: int,
+			period: int,
+			freq: str = "trimestre",
+			base_type: str = "individual",
 		):
 		self.year = year
 		self.period = period
 		self.freq = freq
 		self.base_type = self.folder = base_type
-		super(MicroData, self).__init__(*args, **kwargs)
+		super(MicroData, self).__init__()
 
 	@property
 	def filename(self): return "base_{}_{}{}{}.zip".format(
@@ -58,3 +59,7 @@ class MicroData(Getter, MicroDataValidator):
 			self.freq[0].upper(),
 			self.period
 			)
+
+	def get_df(self, inform_user=True):
+		pd.DataFrame.help = vars_labels
+		return super().get_df(inform_user)
\ No newline at end of file
